' ========================================================================================
' GdipSetLineSigmaBlend
' ========================================================================================

' SED_PBWIN
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"

' ========================================================================================
' The following example creates a linear gradient brush, sets a bell-shaped blend, and
' uses the brush to fill a rectangle. Twice more, the code sets a bell-shaped blend with
' different values and, each time, uses the brush to fill a rectangle.
' ========================================================================================
SUB GDIP_SetLineSigmaBlend (BYVAL hdc AS DWORD)

   LOCAL hStatus AS LONG
   LOCAL pGraphics AS DWORD
   LOCAL pt1 AS POINTF
   LOCAL pt2 AS POINTF
   LOCAL colorRed AS DWORD
   LOCAL colorBlue AS DWORD
   LOCAL pLinBrush AS DWORD

   hStatus = GdipCreateFromHDC(hdc, pGraphics)

   pt1.x = 0 : pt1.y = 0 : pt2.x = 500 : pt2.y = 0
   colorRed = GDIP_ARGB(255, 255, 0, 0)
   colorBlue = GDIP_ARGB(255, 0, 0, 255)

   hStatus = GdipCreateLineBrush(pt1, pt2, colorRed, colorBlue, %WrapModeTile, pLinBrush)

   hStatus = GdipSetLineSigmaBlend(pLinBrush, 0.5, 0.6)
   hStatus = GdipFillRectangle(pGraphics, pLinBrush, 0, 0, 500, 50)

   hStatus = GdipSetLineSigmaBlend(pLinBrush, 0.5, 0.8)
   hStatus = GdipFillRectangle(pGraphics, pLinBrush, 0, 75, 500, 50)

   hStatus = GdipSetLineSigmaBlend(pLinBrush, 0.5, 1.0)
   hStatus = GdipFillRectangle(pGraphics, pLinBrush, 0, 150, 500, 50)

   ' // Cleanup
   IF pLinBrush THEN GdipDeleteBrush(pLinBrush)
   IF pGraphics THEN GdipDeleteGraphics(pGraphics)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION WINMAIN (BYVAL hInstance AS DWORD, BYVAL hPrevInstance AS DWORD, BYVAL lpszCmdLine AS ASCIIZ PTR, BYVAL nCmdShow AS LONG) AS LONG

   LOCAL hr AS LONG
   LOCAL hDlg AS DWORD
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput

   ' Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hr = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hr THEN
      MSGBOX "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   DIALOG NEW 0, "GdipSetLineSigmaBlend", , , 350, 170, %WS_OVERLAPPED OR %WS_THICKFRAME OR %WS_SYSMENU OR _
   %WS_MINIMIZEBOX OR %WS_MAXIMIZEBOX OR %WS_VISIBLE OR %DS_CENTER TO hDlg
   DIALOG SET COLOR hDlg, %BLACK, %WHITE
   DIALOG SHOW MODAL hDlg, CALL DlgProc

   ' Shutdown GDI+
   GdiplusShutdown token

END FUNCTION
' ========================================================================================

' ========================================================================================
' Main Dialog procedure
' ========================================================================================
CALLBACK FUNCTION DlgProc() AS LONG

   LOCAL hDC AS DWORD
   LOCAL ps AS PAINTSTRUCT

   SELECT CASE CBMSG

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

      CASE %WM_PAINT
         hDC = BeginPaint(CBHNDL, ps)
         GDIP_SetLineSigmaBlend hDC
         EndPaint(CBHNDL, ps)

   END SELECT

END FUNCTION
' ========================================================================================
